==> zola-0.14.0.tar.gz: zola-0.14.0/EXAMPLES.md <==
# Example sites

| Site                                                               |                   Source Code                            |
|:-------------------------------------------------------------------|:--------------------------------------------------------:|
| [vincentprouillet.com](https://www.vincentprouillet.com/)          | https://github.com/Keats/vincentprouillet/               |
| [blog.williamdes.eu](http://blog.williamdes.eu/)                   | https://github.com/wdesportes/blog.williamdes.eu         |
| [t-rex.tileserver.ch](https://t-rex.tileserver.ch)                 | https://github.com/t-rex-tileserver/t-rex-website/       |
| [Philipp Oppermann's blog](https://os.phil-opp.com/)               | https://github.com/phil-opp/blog_os/tree/master/blog     |
| [seventeencups](https://www.seventeencups.net)                     | https://github.com/17cupsofcoffee/seventeencups.net      |
| [j1m.net](https://j1m.net)                                         | https://gitlab.com/jwcampbell/j1mnet                     |
| [vaporsoft.net](http://vaporsoft.net)                              | https://github.com/piedoom/vaporsoft                     |
| [verpeteren.nl](http://www.verpeteren.nl)                          |                                                          |
| [atlasreports.nl](http://www.atlasreports.nl)                      |                                                          |
| [groksome.com](http://www.groksome.com)                            |                                                          |
| [tuckersiemens.com](https://tuckersiemens.com)                     | https://github.com/reillysiemens/tuckersiemens.com       |
| [andrewzah.com](https://andrewzah.com)                             | https://git.sr.ht/~andrewzah/personal-site/tree          |
| [Axiomatic Semantics](https://axiomatic.neophilus.net)             | https://github.com/Libbum/AxiomaticSemantics             |
| [Tinkering](https://tinkering.xyz)                                 |                                                          |
| [Daniel Sockwell's codesections.com](https://www.codesections.com) | https://gitlab.com/codesections/codesections-website     |
| [Jens Getreu's blog](https://blog.getreu.net)                      |                                                          |
| [Matthias Endler](https://endler.dev)                              | https://github.com/mre/mre.github.io                     |
| [Michael Plotke](https://michael.plotke.me)                        | https://gitlab.com/bdjnk/michael                         |
| [shaleenjain.com](https://shaleenjain.com)                         | https://github.com/shalzz/shalzz.github.io               |
| [Hello, Rust!](https://hello-rust.show)                            | https://github.com/hello-rust/hello-rust.github.io       |
| [maxdeviant.com](https://maxdeviant.com/)                          |                                                          |
| [Uwes Blog](https://uwe-arzt.de)                                   | https://github.com/uwearzt/site-uwe-arzt                 |
| [ozkriff.games](https://ozkriff.games)                             | https://github.com/ozkriff/ozkriff.github.io-src         |
| [Sylvain Kerkour](https://kerkour.fr)                              | https://gitlab.com/z0mbie42/kerkour.fr                   |
| [CodeShow by Bruno Rocha](https://codeshow.com.br)                 | https://github.com/codeshow/site                         |
| [trevordmiller.com](https://trevordmiller.com)                     | https://github.com/trevordmiller/trevordmiller.github.io |
| [fundon.me](https://fundon.me/)                                    | https://github.com/fundon/fundon.github.io               |
| [rust-gamedev.github.io](https://rust-gamedev.github.io)           | https://github.com/rust-gamedev/rust-gamedev.github.io   |
| [arewegameyet.rs](http://arewegameyet.rs)                          | https://github.com/rust-gamedev/arewegameyet             |
| [klau.si](https://klau.si)                                         | https://github.com/klausi/klau.si                        |
| [peterlyons.com](https://peterlyons.com)                           | https://github.com/focusaurus/peterlyons.com-zola        |
| [blog.turbo.fish](https://blog.turbo.fish)                         | https://git.sr.ht/~jplatte/blog.turbo.fish               |
| [guerinpe.com](https://guerinpe.com)                               | https://github.com/Grelot/blog                           |
| [uggla.fr](https://uggla.fr)                                       | https://uggla.fr                                         |
| [NorthCon e.V.](https://verein.northcon.de/)                       |                                                          |

==> zola-0.14.1.tar.gz: zola-0.14.1/EXAMPLES.md <==
# Example sites

| Site                                                               |                   Source Code                            |
|:-------------------------------------------------------------------|:--------------------------------------------------------:|
| [vincentprouillet.com](https://www.vincentprouillet.com/)          | https://github.com/Keats/vincentprouillet/               |
| [blog.williamdes.eu](http://blog.williamdes.eu/)                   | https://github.com/wdesportes/blog.williamdes.eu         |
| [t-rex.tileserver.ch](https://t-rex.tileserver.ch)                 | https://github.com/t-rex-tileserver/t-rex-website/       |
| [Philipp Oppermann's blog](https://os.phil-opp.com/)               | https://github.com/phil-opp/blog_os/tree/master/blog     |
| [seventeencups](https://www.seventeencups.net)                     | https://github.com/17cupsofcoffee/seventeencups.net      |
| [j1m.net](https://j1m.net)                                         | https://gitlab.com/jwcampbell/j1mnet                     |
| [vaporsoft.net](http://vaporsoft.net)                              | https://github.com/piedoom/vaporsoft                     |
| [verpeteren.nl](http://www.verpeteren.nl)                          |                                                          |
| [atlasreports.nl](http://www.atlasreports.nl)                      |                                                          |
| [groksome.com](http://www.groksome.com)                            |                                                          |
| [tuckersiemens.com](https://tuckersiemens.com)                     | https://github.com/reillysiemens/tuckersiemens.com       |
| [andrewzah.com](https://andrewzah.com)                             | https://git.sr.ht/~andrewzah/personal-site/tree          |
| [Axiomatic Semantics](https://axiomatic.neophilus.net)             | https://github.com/Libbum/AxiomaticSemantics             |
| [Tinkering](https://tinkering.xyz)                                 |                                                          |
| [Daniel Sockwell's codesections.com](https://www.codesections.com) | https://gitlab.com/codesections/codesections-website     |
| [Jens Getreu's blog](https://blog.getreu.net)                      |                                                          |
| [Matthias Endler](https://endler.dev)                              | https://github.com/mre/mre.github.io                     |
| [Michael Plotke](https://michael.plotke.me)                        | https://gitlab.com/bdjnk/michael                         |
| [shaleenjain.com](https://shaleenjain.com)                         | https://github.com/shalzz/shalzz.github.io               |
| [Hello, Rust!](https://hello-rust.show)                            | https://github.com/hello-rust/hello-rust.github.io       |
| [maxdeviant.com](https://maxdeviant.com/)                          |                                                          |
| [Uwes Blog](https://uwe-arzt.de)                                   | https://github.com/uwearzt/site-uwe-arzt                 |
| [ozkriff.games](https://ozkriff.games)                             | https://github.com/ozkriff/ozkriff.github.io-src         |
| [Sylvain Kerkour](https://kerkour.fr)                              | https://gitlab.com/z0mbie42/kerkour.fr                   |
| [CodeShow by Bruno Rocha](https://codeshow.com.br)                 | https://github.com/codeshow/site                         |
| [trevordmiller.com](https://trevordmiller.com)                     | https://github.com/trevordmiller/trevordmiller.github.io |
| [fundon.me](https://fundon.me/)                                    | https://github.com/fundon/fundon.github.io               |
| [rust-gamedev.github.io](https://rust-gamedev.github.io)           | https://github.com/rust-gamedev/rust-gamedev.github.io   |
| [arewegameyet.rs](http://arewegameyet.rs)                          | https://github.com/rust-gamedev/arewegameyet             |
| [klau.si](https://klau.si)                                         | https://github.com/klausi/klau.si                        |
| [peterlyons.com](https://peterlyons.com)                           | https://github.com/focusaurus/peterlyons.com-zola        |
| [blog.turbo.fish](https://blog.turbo.fish)                         | https://git.sr.ht/~jplatte/blog.turbo.fish               |
| [guerinpe.com](https://guerinpe.com)                               | https://github.com/Grelot/blog                           |
| [uggla.fr](https://uggla.fr)                                       | https://github.com/uggla/blog                            |
| [NorthCon e.V.](https://verein.northcon.de/)                       |                                                          |
